@@ -27,7 +27,7 @@ def convertir_liste_signaux_vers_str(liste_signaux):
 def convertir_liste_paires_signaux_vers_str(liste_paires_signaux):
     _str = ""
     for p in liste_paires_signaux:
-        _str += "{0:40}".format(convertir_paire_signaux_vers_str(p))
+        _str += "{0:40}".format(str(p[0]) + " et " + str(p[1]))
     return _str
 
 def afficher_liste_paires_signaux(liste_paires_signaux):
